@@ -7,18 +7,18 @@ use utf8;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-use Carp qw(confess);
+use Carp   qw(confess);
 use Encode qw(decode);
 use JSON;
 use LWP::UserAgent;
 
-our $VERSION = '4.01';
+our $VERSION = '4.03';
 
 sub new {
 	my ( $obj, %conf ) = @_;
 
 	my $lang = $conf{language} // 'd';
-	my $ua = $conf{ua};
+	my $ua   = $conf{ua};
 
 	if ( not $ua ) {
 		my %lwp_options = %{ $conf{lwp_options} // { timeout => 10 } };
@@ -109,7 +109,7 @@ finder services
 	use Travel::Status::DE::HAFAS::StopFinder;
 
 	my $sf = Travel::Status::DE::HAFAS::StopFinder->new(
-		url => 'http://reiseauskunft.bahn.de/bin/ajax-getstop.exe',
+		url => 'https://reiseauskunft.bahn.de/bin/ajax-getstop.exe',
 		input => 'Borbeck',
 	);
 
@@ -123,13 +123,13 @@ finder services
 
 =head1 VERSION
 
-version 4.01
+version 4.03
 
 =head1 DESCRIPTION
 
 Travel::Status::DE::HAFAS::StopFinder is an interface to the stop finder
 service of HAFAS based arrival/departure monitors, for instance the one
-available at L<http://reiseauskunft.bahn.de/bin/ajax-getstop.exe/dn>.
+available at L<https://reiseauskunft.bahn.de/bin/ajax-getstop.exe/dn>.
 
 It takes a string (usually a location or station name) and reports all
 stations and stops which are lexically similar to it.
